@@ -1,8 +1,7 @@
 use aes::Aes256 as Aes256Alg;
 use block_modes::block_padding::Pkcs7;
 use block_modes::{BlockMode, Cbc};
-use serde::de::DeserializeOwned;
-use serde::Serialize;
+use serde::{Deserialize, Serialize};
 
 use crate::auth0::errors::Auth0Error;
 
@@ -22,10 +21,10 @@ pub fn encrypt<T: Serialize>(
     Ok(cipher.encrypt_vec(json.as_bytes()))
 }
 
-pub fn decrypt<T: DeserializeOwned>(
-    token_encryption_key_str: &str,
-    encrypted: &[u8],
-) -> Result<T, Auth0Error> {
+pub fn decrypt<T>(token_encryption_key_str: &str, encrypted: &[u8]) -> Result<T, Auth0Error>
+where
+    for<'de> T: Deserialize<'de>,
+{
     // `unwrap` here is fine because `IV` is set here and the only error returned is: `InvalidKeyIvLength`
     // and this must never happen
     let cipher: Aes256 =
